import wx

ID_NEW_PROJECT   = 12000
ID_OPEN_PROJECT  = 12001
ID_CLOSE_PROJECT = 12002
ID_FINISH        = 12003
ID_CANCEL        = 12004
ID_OPEN          = 12005
ID_COMMAND       = 12006
ID_EDIT_PROJECT  = 12007
ID_EXECUTE       = 12008
ID_CLEAR         = 12009
ID_CLOSE             = 12010
ID_SHOW_ACTION_VIEW  = 12011
ID_SHOW_CONSOLE_VIEW = 12012
ID_APPLY             = 12013
ART_CONSOLE      = "ART_CONSOLE"
ART_ACTION       = "ART_ACTION"
EVT_PLUGIN_FINISHED = wx.NewEventType()