create index LOG_LOGTYPE_CODE_IDX on LOG (LOGTYPE_CODE) tablespace TS_INDEX NOLOGGING;
create index LOG_LOGTYPE_CODE_CA_IDX on LOG (LOGTYPE_CODE,trunc(CREATED_AT)) tablespace TS_INDEX NOLOGGING;
create index LOG_JOB_NAME_IDX on LOG (JOB_NAME) tablespace TS_INDEX NOLOGGING;
create index LOG_JOB_NAME_CA_IDX on LOG (JOB_NAME,trunc(CREATED_AT)) tablespace TS_INDEX NOLOGGING;
create index LOG_CREATED_AT_IDX on LOG (trunc(CREATED_AT)) tablespace TS_INDEX NOLOGGING;
create index LOG_PACKAGE_NAME_IDX on LOG (PACKAGE_NAME) tablespace TS_INDEX NOLOGGING;
create index LOG_PACKAGE_NAME_CA_IDX on LOG (PACKAGE_NAME,trunc(CREATED_AT)) tablespace TS_INDEX NOLOGGING;
create index LOG_METHOD_NAME_IDX on LOG (METHOD_NAME) tablespace TS_INDEX NOLOGGING;
create index LOG_METHOD_NAME_CA_IDX on LOG (METHOD_NAME,trunc(CREATED_AT)) tablespace TS_INDEX NOLOGGING;
create index LOG_UNIQ_SESSION_ID_IDX on LOG (UNIQ_SESSION_ID) tablespace TS_INDEX NOLOGGING;
create index LOG_UNIQ_SESSION_ID_CA_IDX on LOG (UNIQ_SESSION_ID,trunc(CREATED_AT)) tablespace TS_INDEX NOLOGGING;

